@@ -1,10 +1,10 @@
-# -*- coding: utf-8 -*-
-
-import re
-import xml.etree.cElementTree as et
 from io import BytesIO
 from logging import getLogger
 
+import re
+import xml.etree.ElementTree as et
+
+
 log = getLogger(__name__)
 
 
